@@ -11,7 +11,7 @@ class ConfusionMatrix:
         self.y_pred = np.asarray(y_pred, dtype=np.int)
         self.labels = labels or [str(i) for i in range(min(self.y_true), max(self.y_true) + 1)]
 
-    def show(self, title=None, normalize='pred', cmap='viridis', xticks_rotation=70, **kwargs):
+    def show(self, title=None, normalize=None, cmap='viridis', xticks_rotation=70, **kwargs):
         """
         Draw matrix
         :param normalize: bool
